=======================================
Welcome to django-environ documentation
=======================================

Release v\ |release| (`What's new? <changelog>`).

.. include:: ../README.rst
   :start-after: -teaser-begin-
   :end-before: -teaser-end-

Overview
========

.. include:: ../README.rst
   :start-after: -overview-
   :end-before: -project-information-

----

Full Table of Contents
======================

The User Guide
--------------

This part of the documentation, which is mostly prose, begins with some
background information about django-environ, then focuses on step-by-step
instructions for getting the most out of django-environ.

.. toctree::
   :maxdepth: 2

   install
   quickstart


The Community Guide
-------------------

This part of the documentation, which is mostly prose, details the
django-environ ecosystem and community.

.. toctree::
   :maxdepth: 2

   faq
   types
   tips

.. toctree::
   :maxdepth: 1

   deprecations
   changelog


The API Documentation / Guide
-----------------------------

If you are looking for information on a specific function, class, or method,
this part of the documentation is for you.

.. toctree::
   :maxdepth: 2

   api


The Contributor Guide
---------------------

If you want to contribute to the project, this part of the documentation is for
you.

.. toctree::
   :maxdepth: 3

   contributing
   backers
   license

.. include:: ../README.rst
   :start-after: -support-

.. include:: ../README.rst
   :start-after: -project-information-
   :end-before: -support-
